function dimerode
% dimerode simulates the negative feedback model with TF dimerisation

%set the parameters
k1 = 50;
k2 = 1;
d1 = 0.1;
d2 = 0.1;
n = 10;
p0 = 10;
%set the NEW parameters
kD = 1; 
d3 = 0.5*d2; 

negodecompare

%set the time span for simulation
tspan=[0 100];
%set the initial conditions for m, p1 and p2 
x0 = [1;5;5];

%solve the ODEs
[t,x]=ode45(@f,tspan,x0);

figure(1)
subplot(3,1,1)
plot(t,x(:,1),'linewidth',2)
xlabel('time')
ylabel('mRNA')
subplot(3,1,2)
plot(t,x(:,2),'linewidth',2)
xlabel('time')
ylabel('monomer')
subplot(3,1,3)
plot(t,x(:,3),'linewidth',2) 
xlabel('time')
ylabel('dimer/protein')

function dydt=f(t,x) %inputs are time (t) and state (x)
%note that x is a 3-element column vector
%1st entry is mRNA, 2nd entry is monomer, 3rd is dimer
dydt=[k1/(1+(x(3)/p0)^n)-d1*x(1);
        k2*x(1)-d2*x(2)-2*kD*(x(2)^2);
        kD*(x(2)^2)-d3*x(3)];
end
end