function negodecompare
% negodecomparesimulates the negative feedback model
% uses 3 subplots to enable comparison with dimerisation model

%set the parameters - ensure these are the same as in dimerodecompare
k1 = 50;
k2 = 1;
d1 = 0.1;
d2 = 0.1;
n = 10;
p0 = 10;

%set the time span for simulation
tspan = [0 100];
%set the initial conditions for m and p
x0 = [1;5];

%open a figure window
figure(1)
%solve the ODEs
[t,x] = ode45(@f,tspan,x0);
%plot the solution as a function of time
% plot(t,x,'linewidth',2)
subplot(3,1,1) %1st axes
plot(t,x(:,1),'--','linewidth',2) %mRNA
xlabel('time')
ylabel('mRNA')
hold on
subplot(3,1,3) %3rd axes
plot(t,x(:,2),'--','linewidth',2) %protein
xlabel('time')
ylabel('protein')
hold on

%specify the ODE rate functions
function dxdt = f(t,x) 
%inputs are time (t) and state (x)
%note that x is a 2-element column vector
%1st entry is mRNA, 2nd entry is protein
    dxdt = [k1/(1+(x(2)/p0)^n)-d1*x(1); k2*x(1)-d2*x(2)];
end
end